@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2019 Ahmet Öztürk (aoz_2@yahoo.com)
+	Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -26,7 +26,7 @@
 #include "lifeograph.hpp"
 #include "app_window.hpp"
 #include "helpers.hpp"
-#include "diary.hpp"	// for LIFEO::PASSPHRASE_MIN_SIZE
+#include "diary.hpp"    // for LIFEO::PASSPHRASE_MIN_SIZE
 #include "dialog_password.hpp"
 
 
@@ -106,8 +106,8 @@ DialogPassword::launch_internal()
     m_Bx_authenticate->set_visible( m_ot == OT_CHANGE );
     m_E_new->set_sensitive( not( m_ot & OTC_CURRENT ) );
     m_E_confirm->set_sensitive( not( m_ot & OTC_CURRENT ) );
-    m_E_new->get_style_context()->remove_class( "warning" );
-    m_E_confirm->get_style_context()->remove_class( "warning" );
+    m_E_new->get_style_context()->remove_class( "error" );
+    m_E_confirm->get_style_context()->remove_class( "error" );
 
     if( m_ot == OT_CHANGE )
         set_default_widget( *m_B_authenticate );
@@ -161,7 +161,6 @@ DialogPassword::launch_internal()
         m_E_new->grab_focus();
     else
         m_E_current->grab_focus();
-
 }
 
 void
@@ -187,6 +186,8 @@ DialogPassword::handle_go()
             process_wrong_password();
             return;     // do not call go handler
         }
+        else
+            m_path_prev.clear();
     }
 
     if( m_ot == OT_OPEN )
@@ -261,22 +262,22 @@ DialogPassword::check_match()
 
     if( passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
     {
-        m_E_new->get_style_context()->remove_class( "warning" );
+        m_E_new->get_style_context()->remove_class( "error" );
         if( passphrase == m_E_confirm->get_text() )
         {
-            m_E_confirm->get_style_context()->remove_class( "warning" );
+            m_E_confirm->get_style_context()->remove_class( "error" );
             m_B_go->set_sensitive( true );
         }
         else
         {
-            m_E_confirm->get_style_context()->add_class( "warning" );
+            m_E_confirm->get_style_context()->add_class( "error" );
             m_B_go->set_sensitive( false );
         }
     }
     else
     {
-        m_E_new->get_style_context()->add_class( "warning" );
-        m_E_confirm->get_style_context()->add_class( "warning" );
+        m_E_new->get_style_context()->add_class( "error" );
+        m_E_confirm->get_style_context()->add_class( "error" );
         m_B_go->set_sensitive( false );
     }
 }
