@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2010 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -37,27 +37,23 @@ namespace LIFEO
 class DialogPreferences : public DialogEvent
 {
     public:
-        static void                 create();
                                     DialogPreferences( BaseObjectType*,
                                                        const Glib::RefPtr< Gtk::Builder >& );
-        void                        handle_response( int );
-        void                        handle_ChB_autologout_toggled();
-        void                        handle_ChB_ftoolbar_toggled();
-        void                        update_date_format();
+
+        static void                 create();
 
     protected:
-        static DialogPreferences*
-                                    ptr;
-        Gtk::CheckButton*           m_ChB_autologout;
-        Gtk::Box*                   m_Bx_max_idle_time;
-        Gtk::SpinButton*            m_SpB_max_idle_time;
+        void                        update_date_format();
+        void                        handle_response( int );
+
+        static DialogPreferences*   ptr;
+        Gtk::ComboBoxText*          m_CB_autologout;
+        Gtk::Switch*                m_Sw_save_backups;
+        Gtk::FileChooserButton*     m_FCB_backup_path;
         Gtk::ComboBoxText*          m_CB_date_order;
         Gtk::ComboBoxText*          m_CB_date_separator;
-        Gtk::CheckButton*           m_ChB_formatting_toolbar;
-        Gtk::CheckButton*           m_ChB_use_dark_theme;
-
-    private:
-
+        Gtk::RadioButton*           m_RB_units_imperial;
+        Gtk::Switch*                m_Sw_use_dark_theme;
 };
 
 } // end of namespace LIFEO
