@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2019 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -23,12 +23,16 @@
 #include <cassert>
 
 #include "lifeograph.hpp"
+#include "dialog_export.hpp"
 
 using namespace LIFEO;
 
-constexpr char COLOR_IGNORE[]      = "#999999";
-constexpr char COLOR_ADD[]         = "#ccffcc";
+constexpr char COLOR_IGNORE[]      = "#cccccc";
+constexpr char COLOR_IGNORE_FG[]   = "#666666";
 constexpr char COLOR_OVERWRITE[]   = "#d0e0bb";
+constexpr char COLOR_ADD[]         = "#ccffcc";
+constexpr char COLOR_DELETED[]     = "#ffcccc";
+constexpr char COLOR_CHANGED[]     = "#ccccff";
 
 DialogSync::DialogSync( BaseObjectType* cobject,
                         const Glib::RefPtr< Gtk::Builder >& refbuilder )
@@ -159,7 +163,7 @@ DialogSync::DialogSync( BaseObjectType* cobject,
             sigc::mem_fun( this, &DialogSync::handle_TV_action_edited ) );
     m_TVC_action->signal_clicked().connect(
             sigc::mem_fun( this, &DialogSync::show_action_filter ) );
-    m_TVC_status->set_cell_data_func( * m_TV_contents->get_column_cell_renderer( 2 ),
+    m_TVC_action->set_cell_data_func( * m_TV_contents->get_column_cell_renderer( 2 ),
                                       sigc::mem_fun( this, &DialogSync::set_cell_color_a ) );
 
     // FILTERING
@@ -173,27 +177,29 @@ DialogSync::DialogSync( BaseObjectType* cobject,
     CRT_comp_r->property_wrap_mode() = Pango::WRAP_WORD;
     CRT_comp_l->property_wrap_width() = 300;
     CRT_comp_r->property_wrap_width() = 300;
-    CRT_comp_l->property_ellipsize() = Pango::ELLIPSIZE_END;
-    CRT_comp_r->property_ellipsize() = Pango::ELLIPSIZE_END;
-    CRT_comp_l->property_cell_background_rgba() = Gdk::RGBA{ "#b0b0b0" };
-    CRT_comp_r->property_cell_background_rgba() = Gdk::RGBA{ "#b0b0b0" };
     m_LS_compare = Gtk::ListStore::create( m_CR_compare );
     m_TV_compare->set_model( m_LS_compare );
     m_TV_compare->append_column( _( "Name" ), m_CR_compare.name );
     TVC_comp_l->pack_start( *CRT_comp_l );
     TVC_comp_r->pack_start( *CRT_comp_r );
-    TVC_comp_l->add_attribute( CRT_comp_l->property_markup(), m_CR_compare.str_l );
-    TVC_comp_r->add_attribute( CRT_comp_r->property_markup(), m_CR_compare.str_r );
+    TVC_comp_l->add_attribute( CRT_comp_l->property_text(), m_CR_compare.str_l );
+    TVC_comp_r->add_attribute( CRT_comp_r->property_text(), m_CR_compare.str_r );
     TVC_comp_l->set_expand( true );
     TVC_comp_r->set_expand( true );
     m_TV_compare->append_column( *TVC_comp_l );
     m_TV_compare->append_column( *TVC_comp_r );
+    TVC_comp_l->set_cell_data_func( * m_TV_compare->get_column_cell_renderer( 1 ),
+                                      sigc::mem_fun( this, &DialogSync::set_cell_color_comp_l ) );
+    TVC_comp_r->set_cell_data_func( * m_TV_compare->get_column_cell_renderer( 2 ),
+                                      sigc::mem_fun( this, &DialogSync::set_cell_color_comp_r ) );
 
     // BUTTONS
     set_widget_css( B_ignore, Ustring::compose( "button { background: %1 }", COLOR_IGNORE ) );
     set_widget_css( m_B_ow, Ustring::compose( "button { background: %1 }", COLOR_OVERWRITE ) );
     set_widget_css( m_B_add, Ustring::compose( "button { background: %1 }", COLOR_ADD ) );
 
+    m_tag_widget->set_diary( Diary::d );
+
     // SIGNALS
     m_B_apply_scheme->signal_clicked().connect(
             sigc::mem_fun( this, &DialogSync::update_maps ) );
@@ -220,9 +226,9 @@ DialogSync::DialogSync( BaseObjectType* cobject,
             sigc::mem_fun( this, &DialogSync::open_remote_diary ) );
 
     m_B_go->signal_clicked().connect(
-            sigc::bind( sigc::mem_fun( this, &DialogEvent::response ), RESPONSE_GO ) );
+            sigc::bind( sigc::mem_fun( this, &DialogEvent::response ), Result::OK ) );
     m_B_cancel->signal_clicked().connect(
-            sigc::bind( sigc::mem_fun( this, &DialogEvent::response ), RESPONSE_CANCEL ) );
+            sigc::bind( sigc::mem_fun( this, &DialogEvent::response ), Result::ABORTED ) );
 
     m_IB_sync->signal_response().connect( [ this ]( int ){ m_IB_sync->set_visible( false ); } );
 }
@@ -245,8 +251,6 @@ DialogSync::on_show()
     m_FCB_diary->unselect_all();
     m_tag_widget->clear();
 
-    m_tag_widget->populate();
-
     m_FCB_diary->grab_focus();
 
     m_content_filter = FILTER_DEFAULT;
@@ -319,7 +323,7 @@ DialogSync::ask_for_password()
 void
 DialogSync::update_maps()
 {
-    PRINT_DEBUG( "DialogImport::handle_scheme_changed()" );
+    PRINT_DEBUG( "DialogSync::update_maps()" );
 
     m_comparison_map.clear();
     m_action_map.clear();
@@ -339,8 +343,7 @@ DialogSync::update_maps()
                 m_action_map[ kv_elem.first ] = SI::OVERWRITE;
             else //if( m_RB_changed_add->get_active() )
                 m_action_map[ kv_elem.first ] =
-                        ( elem_l->get_type() == DiaryElement::ET_ENTRY ||
-                          elem_l->get_type() == DiaryElement::ET_TAG ) ?
+                        ( elem_l->get_type() == DiaryElement::ET_ENTRY ) ?
                                 SI::ADD : SI::OVERWRITE;
 
             if( m_flag_identical )
@@ -374,14 +377,14 @@ DialogSync::handle_TV_selection_changed()
     m_B_ow->set_visible( false );
     m_B_add->set_visible( false );
 
-    Gtk::TreeIter iter{ m_TV_contents->get_selection()->get_selected() };
+    auto&&              iter{ m_TV_contents->get_selection()->get_selected() };
 
     if( !iter )
         return;
 
-    Gtk::TreeRow row{ *( iter ) };
+    Gtk::TreeRow        row{ *( iter ) };
     const DiaryElement* elem_r{ row[ m_TS_content->colrec.ptr ] };
-    const SI si{ row[ m_TS_content->colrec.comp_res ] };
+    const SI            si{ row[ m_TS_content->colrec.comp_res ] };
 
     if( elem_r == nullptr || si == SI::INTACT )
         return;
@@ -391,7 +394,6 @@ DialogSync::handle_TV_selection_changed()
     switch( elem_r->get_type() )
     {
         case DiaryElement::ET_ENTRY:
-        case DiaryElement::ET_TAG:
             m_B_add->set_visible( true );
             m_B_ow->set_visible( si == SI::CHANGED );
             break;
@@ -403,85 +405,100 @@ DialogSync::handle_TV_selection_changed()
 
     const DiaryElement* elem_l{ Diary::d->get_corresponding_elem( elem_r ) };
 
-    static const Ustring tpl[] = { "<span color=\"red\">∅</span>", // 0: DELETED
-                                   "<span color=\"green\">%1</span>", // 1: NEW
-                                   "<span color=\"blue\">%1</span>", // 2: CHANGED
-                                   "<span color=\"%1\">%2</span>" };
-
-    auto add_item = [ & ]( const SI id, const Ustring& str_l,
-                           const Ustring& str_r, int l, int r )
+    auto add_item = [ & ]( const SI id, const Ustring& str_l, const Ustring& str_r, SI result )
     {
         row = * ( m_LS_compare->append() );
 
         row[ m_CR_compare.name ] = STR0/id;
-        row[ m_CR_compare.str_l ] =
-                Ustring::compose( tpl[ l ], Glib::Markup::escape_text( str_l ) );
-        row[ m_CR_compare.str_r ] =
-                Ustring::compose( tpl[ r ], Glib::Markup::escape_text( str_r ) );
+        row[ m_CR_compare.str_l ] = str_l;
+        row[ m_CR_compare.str_r ] = str_r;
+        row[ m_CR_compare.result ] = result;
     };
 
     if( elem_l )
     {
-        const SKVVec props_l = elem_l->get_as_string();
-        const SKVVec props_r = elem_r->get_as_string();
-        const int loop_size{ max( props_l.size(), props_r.size() ) };
-        unsigned i_l{ 0 }, i_r{ 0 };
+        const SKVVec&&  props_l{ elem_l->get_as_skvvec() };
+        const SKVVec&&  props_r{ elem_r->get_as_skvvec() };
+        unsigned        i_l{ 0 }, i_r{ 0 };
 
-        for( int i = 0; i < loop_size; i++ )
+        while( i_l < props_l.size() || i_r < props_r.size() )
         {
+            // PAST THE END OF THE LOCAL ITEMS - ADD AS A DELETED ITEM
             if( i_l >= props_l.size() )
             {
-                add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, 0, 1 );
+                add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, SI::DELETED );
                 i_r++;
             }
+            // PAST THE END OF THE REMOTE ITEMS - ADD AS A NEW ITEM
             else
             if( i_r >= props_r.size() )
             {
-                add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", 1, 0 );
+                add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", SI::NEW );
                 i_l++;
             }
+            // DIFFERENT TYPE OF ITEM - NEW OR DELETED ITEM DEPENDING ON THE COMPARSION OF ORDERS
             else
             if( props_l[ i_l ].first != props_r[ i_r ].first )
             {
                 if( props_l[ i_l ].first < props_r[ i_r ].first )
                 {
-                    add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", 1, 0 );
+                    add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", SI::NEW );
                     i_l++;
                 }
                 else
                 {
-                    add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, 0, 1 );
+                    add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, SI::DELETED );
                     i_r++;
                 }
             }
+            // DIFFERENT ITEM VALUES
             else
             if( props_l[ i_l ].second != props_r[ i_r ].second )
             {
-                if( i_l + 1 < props_l.size() &&
-                    props_l[ i_l + 1 ].first == props_r[ i_r ].first &&
-                    props_l[ i_l + 1 ].second == props_r[ i_r ].second )
+                int j_l{ -1 }, j_r{ -1 };
+                // LOOK DOWN IN LOCAL ITEMS TO SEE IF THERE IS A MATCH.
+                // if so, that will mean new item in local
+                for( int i = 1; i_l + i < props_l.size(); i++ )
+                    if( props_l[ i_l + i ].first == props_r[ i_r ].first &&
+                        props_l[ i_l + i ].second == props_r[ i_r ].second )
+                    {
+                        j_l = i;
+                        break;
+                    }
+                // LOOK DOWN IN REMOTE ITEMS TO SEE IF THERE IS A MATCH.
+                // if so, that will mean deleted item in local
+                for( int i = 1; i_r + i < props_r.size(); i++ )
+                    if( props_l[ i_l ].first == props_r[ i_r + i ].first &&
+                        props_l[ i_l ].second == props_r[ i_r + i ].second )
+                    {
+                        j_r = i;
+                        break;
+                    }
+
+                if( j_l > 0 && ( j_r < 0 || j_l <= j_r ) )
                 {
-                    add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", 1, 0 );
+                    add_item( props_l[ i_l ].first, props_l[ i_l ].second, "", SI::NEW );
                     i_l++;
                 }
                 else
-                if( i_r + 1 < props_r.size() &&
-                    props_l[ i_l ].first == props_r[ i_r + 1 ].first &&
-                    props_l[ i_l ].second == props_r[ i_r + 1 ].second )
+                if( j_r > 0 && ( j_l < 0 || j_r <= j_l ) )
                 {
-                    add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, 0, 1 );
+                    add_item( props_r[ i_r ].first, "", props_r[ i_r ].second, SI::DELETED );
                     i_r++;
                 }
                 else
                 {
                     add_item( props_l[ i_l ].first, props_l[ i_l ].second,
-                              props_r[ i_r ].second, 2, 2 );
+                              props_r[ i_r ].second, SI::CHANGED );
                     i_l++;
                     i_r++;
                 }
             }
             else
             {
+                if(props_l[ i_l ].second.empty() == false )
+                    add_item( props_l[ i_l ].first, props_l[ i_l ].second,
+                              props_r[ i_r ].second, SI::INTACT );
                 i_l++;
                 i_r++;
             }
@@ -577,11 +594,11 @@ DialogSync::change_action( SI si )
 void
 DialogSync::populate_content()
 {
-    auto add_header = [ & ]( const Icon& icon, int header_type )
+    auto add_header = [ & ]( int header_type )
     {
         Gtk::TreeRow row{ * m_TS_content->append() };
         row[ m_TS_content->colrec.ptr ] = nullptr;
-        row[ m_TS_content->colrec.icon ] = icon;
+        //row[ m_TS_content->colrec.icon ] = icon;
         row[ m_TS_content->colrec.header_type ] = header_type;
         row[ m_TS_content->colrec.comp_res ] = SI::_NONE_;
         return row;
@@ -603,7 +620,6 @@ DialogSync::populate_content()
         switch( elem->get_type() )
         {
             case DiaryElement::ET_ENTRY:
-            case DiaryElement::ET_TAG:
                 return( si == SI::NEW ? m_LS_action_add : m_LS_action_add_ow );
             default:
                 return( si == SI::NEW ? m_LS_action_add : m_LS_action_ow );
@@ -637,83 +653,78 @@ DialogSync::populate_content()
     Gtk::TreePath path_top, path_btm;
     m_TV_contents->get_visible_range( path_top, path_btm );
 
+    m_TV_contents->unset_model();
     m_TS_content->clear();
 
-    // ADD ELEMENTS
-    Gtk::TreeRow row_tag_ctgs =
-            add_header( Lifeograph::icons->tag_category_16, TreeStoreImport::HT_TAG_CTGS );
-    Gtk::TreeRow row_tags =
-            add_header( Lifeograph::icons->tag_16, TreeStoreImport::HT_TAGS );
-    Gtk::TreeRow row_topics =
-            add_header( Lifeograph::icons->chapter_ordr_16, TreeStoreImport::HT_NMBR_CHAPTERS );
-    Gtk::TreeRow row_groups =
-            add_header( Lifeograph::icons->chapter_free_16, TreeStoreImport::HT_FREE_CHAPTERS );
-    Gtk::TreeRow row_entries =
-            add_header( Lifeograph::icons->entry_16, TreeStoreImport::HT_ENTRIES );
+    // CHAPTER CATEGORIES
+    Gtk::TreeRow row_header, row_chapter;
+    for( auto& kv_ctg : m_diary->m_chapter_categories )
+    {
+        SI cmp_res{ m_comparison_map[ kv_ctg.second->get_id() ] };
+        row_header = add_header( TreeStoreImport::HT_CHAPTER_CTG );
+        // Chapter Categories are not plain headers but also elements per se
+        // so we set element related fields manually:
+        row_header[ m_TS_content->colrec.ptr ] = kv_ctg.second;
+        row_header[ m_TS_content->colrec.status ] = STR0/cmp_res;
+        row_header[ m_TS_content->colrec.action ] = STR0/m_action_map[ kv_ctg.second->get_id() ];
+        row_header[ m_TS_content->colrec.comp_res ] = cmp_res;
+        // DATED CHAPTERS
+        for( auto& kv_chapter : * kv_ctg.second )
+            add_elem( kv_chapter.second, row_header );
+
+        if( cmp_res == SI::INTACT && row_header.children().empty() )
+            m_TS_content->erase( row_header );
+        else
+            update_header( row_header, kv_ctg.second->get_name(), kv_ctg.second->size() );
+    }
+
+    // OTHER ELEMENTS
+    auto&& row_header_entries{ add_header( TreeStoreImport::HT_ENTRIES ) };
+    auto&& row_header_themes{ add_header( TreeStoreImport::HT_THEMES ) };
+    auto&& row_header_filters{ add_header( TreeStoreImport::HT_FILTERS ) };
+    auto&& row_header_charts{ add_header( TreeStoreImport::HT_CHARTS ) };
+    auto&& row_header_tables{ add_header( TreeStoreImport::HT_TABLES ) };
     for( auto& kv_elem : m_action_map )
     {
         DiaryElement* elem{ m_diary->get_element( kv_elem.first ) };
         switch( elem->get_type() )
         {
-            case DiaryElement::ET_TAG_CTG:
-                add_elem( elem, row_tag_ctgs );
-                break;
-            case DiaryElement::ET_TAG:
-                add_elem( elem, row_tags );
-                break;
-            case DiaryElement::ET_TOPIC:
-                add_elem( elem, row_topics );
-                break;
-            case DiaryElement::ET_GROUP:
-                add_elem( elem, row_groups );
-                break;
             case DiaryElement::ET_ENTRY:
-                add_elem( elem, row_entries );
+                add_elem( elem, row_header_entries );
+                break;
+            case DiaryElement::ET_THEME:
+                add_elem( elem, row_header_themes );
+                break;
+            case DiaryElement::ET_FILTER:
+                add_elem( elem, row_header_filters );
+                break;
+            case DiaryElement::ET_CHART:
+                add_elem( elem, row_header_charts );
+                break;
+            case DiaryElement::ET_TABLE:
+                add_elem( elem, row_header_tables );
                 break;
             default:
                 break;
         }
     }
-    update_header( row_tag_ctgs, _( "TAG CATEGORIES" ), m_diary->m_tag_categories.size() );
-    update_header( row_tags, _( "TAGS" ), m_diary->get_tags()->size() );
-    update_header( row_topics, _( "NUMBERED CHAPTERS" ), m_diary->m_topics->size() );
-    update_header( row_groups, _( "FREE CHAPTERS" ), m_diary->m_groups->size() );
-    update_header( row_entries, _( "ENTRIES" ), m_diary->get_entries().size() );
-
-    // CHAPTER CATEGORIES
-    Gtk::TreeRow row, row2;
-    for( auto& kv_ctg : m_diary->m_chapter_categories )
-    {
-        SI cmp_res{ m_comparison_map[ kv_ctg.second->get_id() ] };
-        row = add_header( Lifeograph::icons->chapter_temp_16, TreeStoreImport::HT_CHAPTER_CTG );
-        // Chapter Categories are not plain headers but also elements per se
-        // so we set element related fields manually:
-        row[ m_TS_content->colrec.ptr ] = kv_ctg.second;
-        row[ m_TS_content->colrec.status ] = STR0/cmp_res;
-        row[ m_TS_content->colrec.action ] = STR0/m_action_map[ kv_ctg.second->get_id() ];
-        row[ m_TS_content->colrec.comp_res ] = cmp_res;
-        // DATED CHAPTERS
-        for( auto& kv_chapter : * kv_ctg.second )
-            add_elem( kv_chapter.second, row );
-
-        if( cmp_res == SI::INTACT && row.children().empty() )
-            m_TS_content->erase( row );
-        else
-            update_header( row, kv_ctg.second->get_name(), kv_ctg.second->size() );
-    }
+    update_header( row_header_entries, _( "ENTRIES" ), m_diary->m_entries.size() );
+    update_header( row_header_themes, _( "THEMES" ), m_diary->m_themes.size() );
+    update_header( row_header_filters, _( "FILTERS" ), m_diary->m_filters.size() );
+    update_header( row_header_charts, _( "CHARTS" ), m_diary->m_charts.size() );
+    update_header( row_header_tables, _( "TABLES" ), m_diary->m_tables.size() );
 
+    m_TV_contents->set_model( m_TS_content );
     m_TV_contents->expand_all();
-    if( path_top.size() > 0 )
-    {
-        m_TV_contents->scroll_to_row( path_top );
-        m_TV_contents->scroll_to_row( path_btm );
-    }
+
+    if( path_top.empty() == false )
+        m_TV_contents->scroll_to_row( path_top, 0.0 );
 }
 
 void
 DialogSync::set_cell_color_s( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
 {
-    Gdk::RGBA color_b{ "#b0b0b0" };
+    Gdk::RGBA color_b{ COLOR_IGNORE };
     Gdk::RGBA color_f{ "#000000" };
 
     switch( ( * iter )[ m_TS_content->colrec.comp_res ]  )
@@ -742,26 +753,76 @@ void
 DialogSync::set_cell_color_a( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
 {
     DiaryElement* elem{ ( * iter )[ m_TS_content->colrec.ptr ] };
-    Gdk::RGBA color_b{ "#b0b0b0" };
-    Gdk::RGBA color_f{ "#000000" };
 
     if( elem != nullptr )
     {
         switch( m_action_map[ elem->get_id() ] )
         {
             case SI::ADD:
-                color_b.set( COLOR_ADD );
+                cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_ADD );
                 break;
             case SI::OVERWRITE:
-                color_b.set( COLOR_OVERWRITE );
+                cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_OVERWRITE );
                 break;
             default:
-                color_b.set( COLOR_IGNORE );
+                cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_IGNORE );
                 break;
         }
     }
+    else
+        cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_IGNORE );
+
+    dynamic_cast< Gtk::CellRendererText* >( cell )->property_foreground_rgba() =
+            Gdk::RGBA( "#000000" );
+}
+
+void
+DialogSync::set_cell_color_comp_l( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
+{
+    Gdk::RGBA   color_f{ "#000000" };
+
+    switch( ( * iter )[ m_CR_compare.result ] )
+    {
+        case SI::NEW:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_ADD );
+            break;
+        case SI::CHANGED:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_CHANGED );
+            break;
+        case SI::DELETED:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_DELETED );
+            break;
+        default:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_IGNORE );
+            color_f.set( COLOR_IGNORE_FG );
+            break;
+    }
+
+    dynamic_cast< Gtk::CellRendererText* >( cell )->property_foreground_rgba() = color_f;
+}
+
+void
+DialogSync::set_cell_color_comp_r( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
+{
+    Gdk::RGBA   color_f{ "#000000" };
+
+    switch( ( * iter )[ m_CR_compare.result ] )
+    {
+        case SI::NEW:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_DELETED );
+            break;
+        case SI::CHANGED:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_CHANGED );
+            break;
+        case SI::DELETED:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_ADD );
+            break;
+        default:
+            cell->property_cell_background_rgba() = Gdk::RGBA( COLOR_IGNORE );
+            color_f.set( COLOR_IGNORE_FG );
+            break;
+    }
 
-    cell->property_cell_background_rgba() = color_b;
     dynamic_cast< Gtk::CellRendererText* >( cell )->property_foreground_rgba() = color_f;
 }
 
@@ -787,10 +848,12 @@ DialogSync::set_not_ready( const Ustring& message )
     m_B_go->set_sensitive( false );
     m_B_apply_scheme->set_sensitive( false );
 
+    m_LS_compare->clear();
+    m_TS_content->clear();
+    m_action_map.clear();
+
     if( m_diary )
     {
-        m_TS_content->clear();
-        m_action_map.clear();
         delete m_diary;
         m_diary = nullptr;
     }
@@ -804,65 +867,59 @@ DialogSync::set_not_ready( const Ustring& message )
 void
 DialogSync::on_response( int response )
 {
-    if( response == RESPONSE_GO )
+    if( response == Result::OK )
     {
         // prepare the new tag
-        Tag* tag_all{ nullptr };
-        NameAndValue nav{ m_tag_widget->get_nav() };
-        SI filter;
+        Entry*  tag_all{ m_tag_widget->get_entry_create( Diary::d ) };
+        SI      action;
 
-        if( ! nav.name.empty() )
-            tag_all = ( nav.status & NameAndValue::HAS_VALUE ?
-                    Diary::d->create_tag( nav.name, nullptr, ChartPoints::DEFAULT ) :
-                    Diary::d->create_tag( nav.name, nullptr ) );
-
-        for( auto& kv_tag_ctg : m_diary->m_tag_categories )
+        for( auto& kv_theme : m_diary->m_themes )
         {
-            filter = m_action_map[ kv_tag_ctg.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_tag_ctg( kv_tag_ctg.second, filter == SI::ADD );
+            action = m_action_map[ kv_theme.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_theme( kv_theme.second, action == SI::ADD );
         }
 
-        for( auto& kv_tag : m_diary->m_tags )
+        for( auto& kv_filter : m_diary->m_filters )
         {
-            filter = m_action_map[ kv_tag.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_tag( kv_tag.second, filter == SI::ADD );
+            action = m_action_map[ kv_filter.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_filter( kv_filter.second, action == SI::ADD );
+        }
+
+        for( auto& kv_chart : m_diary->m_charts )
+        {
+            action = m_action_map[ kv_chart.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_chart( kv_chart.second, action == SI::ADD );
+        }
+
+        for( auto& kv_table : m_diary->m_tables )
+        {
+            action = m_action_map[ kv_table.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_table( kv_table.second, action == SI::ADD );
         }
 
         for( auto& kv_cpt_ctg : m_diary->m_chapter_categories )
         {
-            filter = m_action_map[ kv_cpt_ctg.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_chapter_ctg( kv_cpt_ctg.second, filter == SI::ADD );
+            action = m_action_map[ kv_cpt_ctg.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_chapter_ctg( kv_cpt_ctg.second, action == SI::ADD );
 
             for( auto& kv_cpt : * kv_cpt_ctg.second )
             {
-                filter = m_action_map[ kv_cpt.second->get_id() ];
-                if( filter != SI::SI_IGNORE )
-                    Diary::d->import_chapter( kv_cpt.second, filter == SI::ADD );
+                action = m_action_map[ kv_cpt.second->get_id() ];
+                if( action != SI::SI_IGNORE )
+                    Diary::d->import_chapter( kv_cpt.second, action == SI::ADD );
             }
         }
 
-        for( auto& kv_topic : *( m_diary->m_topics ) )
-        {
-            filter = m_action_map[ kv_topic.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_chapter( kv_topic.second, filter == SI::ADD );
-        }
-
-        for( auto& kv_group : *( m_diary->m_groups ) )
-        {
-            filter = m_action_map[ kv_group.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_chapter( kv_group.second, filter == SI::ADD );
-        }
-
         for( auto& kv_entry : m_diary->m_entries )
         {
-            filter = m_action_map[ kv_entry.second->get_id() ];
-            if( filter != SI::SI_IGNORE )
-                Diary::d->import_entry( kv_entry.second, tag_all, nav.value, filter == SI::ADD );
+            action = m_action_map[ kv_entry.second->get_id() ];
+            if( action != SI::SI_IGNORE )
+                Diary::d->import_entry( kv_entry.second, tag_all, action == SI::ADD );
         }
     }
 
