@@ -177,7 +177,7 @@ Paragraph::has_tag( const Entry* tag ) const
 bool
 Paragraph::has_tag_planned( const Entry* tag ) const
 {
-    return( m_tags_planned.find( tag->get_name() ) != m_tags.end() );
+    return( m_tags_planned.find( tag->get_name() ) != m_tags_planned.end() );
 }
 
 bool
