@@ -292,7 +292,7 @@ Entry::set_name( const Ustring& new_name )
 void
 Entry::update_name()
 {
-    if( m_paragraphs.empty() )
+    if( is_empty() )
         m_name = _( STRING::EMPTY_ENTRY_TITLE );
     else
         m_name = m_paragraphs.front()->get_text();
@@ -550,7 +550,9 @@ Entry::insert_text( UstringSize pos, const Ustring& text )
         para->insert_text( pos - para_offset, text );
 
     set_date_edited( time( nullptr ) );
-    update_name();
+
+    if( pos <= m_paragraphs.front()->get_size() )
+        update_name();
 }
 
 void
@@ -602,6 +604,9 @@ Entry::erase_text( const UstringSize pos_bgn, const UstringSize pos_end )
     para_bgn->erase_text( pos_bgn - para_offset_bgn, pos_end - pos_bgn );
 
     set_date_edited( time( nullptr ) );
+
+    if( m_paragraphs.empty() || pos_bgn <= m_paragraphs.front()->get_size() )
+        update_name();
 }
 
 void
