@@ -50,11 +50,12 @@ class Entry : public DiaryElement
 
         bool                    is_empty() const
         {
-            for( auto& para : m_paragraphs )
-                if( para->is_empty() == false )
-                    return false;
-
-            return true;
+            switch( m_paragraphs.size() )
+            {
+                case 0:  return true;
+                case 1:  return m_paragraphs.front()->is_empty();
+                default: return false;
+            }
         }
         Ustring                 get_text() const;
         void                    clear_text();
