@@ -537,7 +537,7 @@ midtone( const Color& c1, const Color& c2 )
 }
 
 Color
-midtone( const Color& c1, const Color& c2, float ratio )
+midtone( const Color& c1, const Color& c2, double ratio )
 {
     Color midtone;
     midtone.set_red_u( ( c1.get_red_u() * ( 1.0 - ratio ) ) + ( c2.get_red_u() * ratio ) );
