@@ -760,7 +760,7 @@ convert_gdkrgba_to_string( const Color& gdkcolor )
 
 Color               contrast2( const Color&, const Color&, const Color& );
 Color               midtone( const Color&, const Color& );
-Color               midtone( const Color&, const Color&, float );
+Color               midtone( const Color&, const Color&, double );
 
 // FILE OPERATIONS =================================================================================
 #ifdef _WIN32
