@@ -33,11 +33,11 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "2.0.2"
+const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "2.0.3"
 #if LIFEOGRAPH_DEBUG_BUILD || defined( LIFEOGRAPH_BETA_STAGE )
         "\n" BUILD_TIMESTAMP
 #endif
-        "\n\"freedom from trade...\"";
+        "\n\"Spring of Goliath\"";
 
 
 Lifeograph*                     Lifeograph::p;
@@ -68,7 +68,7 @@ std::string                     Lifeograph::LOCALEDIR;
 
 // CONSTRUCTOR
 Lifeograph::Lifeograph()
-:   Gtk::Application( "lifeograph.app",
+:   Gtk::Application( "net.sourceforge.Lifeograph",
                       Gio::APPLICATION_NON_UNIQUE | Gio::APPLICATION_HANDLES_COMMAND_LINE )
 {
     p = this;
@@ -141,12 +141,12 @@ Lifeograph::on_startup()
     add_action( "about", sigc::ptr_fun( &AppWindow::show_about ) );
     add_action( "quit", sigc::hide_return( sigc::mem_fun( this, &Lifeograph::quit ) ) );
 
-    m_menu = Gio::Menu::create();
+    /*m_menu = Gio::Menu::create();
     m_menu->append( _( "Preferences" ), "app.preferences" );
     m_menu->append( _( "About Lifeograph" ), "app.about" );
     m_menu->append( _( "Quit" ), "app.quit" );
 
-    set_app_menu( m_menu );
+    set_app_menu( m_menu );*/
 
     // WORK-AROUD THE GTKMM BUG THAT SURFACES WHEN LTO IS ENABLED (such as in Fedora 33)
     g_type_ensure( TextviewDiaryEdit::get_type() );
