@@ -195,7 +195,7 @@ class Lifeograph : public Gtk::Application
         static bool                 m_flag_ui2_loaded;
 
         // APPLICATION MENU
-        Glib::RefPtr< Gio::Menu >   m_menu;
+        //Glib::RefPtr< Gio::Menu >   m_menu;
 };
 
 } // end of namespace LIFEO
