@@ -196,7 +196,8 @@ ParserText::reset( UstringSize bgn, UstringSize end )
     m_word_cur.clear();
     m_word_count = 0;
     m_int_last = 0;
-    m_date_last = 0;
+    m_date_last.m_date = 0;
+    i_search = 0;
 
     for( auto r : m_active_recipes )
         delete r;
@@ -216,13 +217,31 @@ void
 ParserText::set_search_str( const Ustring& str )
 {
     m_search_str = str;
-    i_search = 0;
     i_search_end = str.size() - 1;
 }
 
 void
 ParserText::parse( const UstringSize bgn, const UstringSize end )
 {
+    auto check_search_char = [&]() -> bool {
+        if( m_search_str[ i_search ] == char_lower( m_char_cur ) )
+        {
+            if( i_search == 0 )
+               m_pos_search = m_pos_cur;
+            if( i_search == i_search_end )
+            {
+               apply_match();
+               i_search = 0;
+            }
+            else
+               i_search++;
+
+            return true;
+        }
+        else
+            return false;
+    };
+
     reset( bgn, end );
 
     if( bgn == 0 )
@@ -238,20 +257,11 @@ ParserText::parse( const UstringSize bgn, const UstringSize end )
 
         if( !m_search_str.empty() )
         {
-            if( m_search_str[ i_search ] == char_lower( m_char_cur ) )
+            if( !check_search_char() && i_search > 0 )
             {
-                if( i_search == 0 )
-                    m_pos_search = m_pos_cur;
-                if( i_search == i_search_end )
-                {
-                    apply_match();
-                    i_search = 0;
-                }
-                else
-                    i_search++;
-            }
-            else
                 i_search = 0;
+                check_search_char();
+            }
         }
 
         // MARKUP PARSING
