@@ -352,8 +352,12 @@ EntryParserPango::add_diary_cover()
     if( m_opt_use_theme_font )
         m_font = ThemeSystem::get()->font;
 
-    add_printable( new PrintableImage( Lifeograph::icons->diary_32,
-                                       m_margin_x + m_page_w / 2 - 16, m_total_h_cur ));
+    Icon&& pixbuf{ Lifeograph::icons->diary_32->scale_simple( m_todo_icon_h * 2,
+                                                              m_todo_icon_h * 2,
+                                                              Gdk::INTERP_BILINEAR ) };
+    add_printable( new PrintableImage( pixbuf,
+                                       m_margin_x + m_page_w / 2 - m_todo_icon_h,
+                                       m_total_h_cur ));
 
     m_marked_up_text = STR::compose( "<span size='xx-large'>",
                                      Glib::Markup::escape_text( Diary::d->get_name() ),
