@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2018 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2020 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -25,18 +25,10 @@
 
 
 #include <map>
-#include <libintl.h>
 
 #include "helpers.hpp"
 
 
-// DEFINITIONS FOR LIBGETTEXT
-#define _(String)               gettext(String)
-#define gettext_noop(String)    String
-#define N_(String)              gettext_noop(String)
-// END OF LIBGETTEXT DEFINITIONS
-
-
 namespace LIFEO
 {
 
@@ -55,19 +47,26 @@ enum class SI
     CHANGED,
     CHART_INTERVALS,
     CHART_UNDERLAY,
+    COLOR,
     CUMULATIVE,
     DATE,
+    DEFINITION,
     DELETED,
     DONE,
+    EDIT_DATE,
     FAVORED,
     ID,
     SI_IGNORE,  // SI_ added to eliminate conflict on Windows
     INTACT,
     LANGUAGE,
+    LOCATION,
+    MAP_PATH,
     MONTHLY,
+    NA, // Not Applicable
     NAME,
     NEW,
     NO,
+    NONE,
     OTHER,
     OVERWRITE,
     PROGRESSED,
@@ -90,65 +89,101 @@ enum class SI
     TAG,
     PARAGRAPH,
 
+    //MONTHS
+    JANUARY,
+    FEBRUARY,
+    MARCH,
+    APRIL,
+    MAY,
+    JUNE,
+    JULY,
+    AUGUST,
+    SEPTEMBER,
+    OCTOBER,
+    NOVEMBER,
+    DECEMBER,
+
     EOENUM // fixed last item
 };
 
 
-typedef std::vector< Ustring > StringVector;
-typedef std::pair< const Ustring, const Ustring > StringPair;
-typedef std::pair< const SI, const Ustring > StringKeyValuePair;
+typedef std::pair< const SI, const HELPERS::Ustring > StringKeyValuePair;
 typedef std::vector< StringKeyValuePair > SKVVec;
-typedef std::map< SI, const Ustring > StrMap;
+typedef std::map< SI, const HELPERS::Ustring > StrMap;
 
 static const StrMap STR0 =
 {
     { SI::_NONE_,       "" },
-    { SI::ADD,          _( "ADD" ) },
-    { SI::AUTO,         _( "Auto" ) },
-    { SI::AVERAGE,      _( "Average" ) },
-    { SI::BOOLEAN,      _( "Boolean" ) },
-    { SI::CANCELED,     _( "Canceled" ) },
-    { SI::CATEGORY,     _( "Category" ) },
-    { SI::CHANGED,      _( "CHANGED" ) },
-    { SI::CHART_INTERVALS,  _( "Chart Intervals" ) },
-    { SI::CHART_UNDERLAY,   _( "Chart Underlay" ) },
-    { SI::CUMULATIVE,   _( "Cumulative" ) },
-    { SI::DATE,         _( "Date" ) },
-    { SI::DELETED,      _( "DELETED" ) },
-    { SI::DONE,         _( "Done" ) },
-    { SI::FAVORED,      _( "Favored" ) },
-    { SI::ID,           _( "ID" ) },
-    { SI::SI_IGNORE,    _( "IGNORE" ) },
-    { SI::INTACT,       _( "INTACT" ) },
-    { SI::LANGUAGE,     _( "Language" ) },
-    { SI::MONTHLY,      _( "Monthly" ) },
-    { SI::NAME,         _( "Name" ) },
-    { SI::NEW,          _( "NEW" ) },
-    { SI::NO,           _( "No" ) },
-    { SI::OTHER,        _( "OTHER" ) },
-    { SI::OVERWRITE,    _( "OVERWRITE" ) },
-    { SI::PARAGRAPH,    _( "Paragraph" ) },
-    { SI::PROGRESSED,   _( "Progressed" ) },
-    { SI::TAG,          _( "Tag" ) },
-    { SI::TYPE_NAME,    _( "Type Name" ) },
-    { SI::THEME,        _( "Theme" ) },
-    { SI::THEME_BASE,   _( "Theme Base" ) },
-    { SI::THEME_FONT,   _( "Theme Font" ) },
-    { SI::THEME_HEADING,    _( "Theme Heading" ) },
-    { SI::THEME_HIGHLIGHT,  _( "Theme Highlight" ) },
-    { SI::THEME_SUBHEADING, _( "Theme Subheading" ) },
-    { SI::THEME_TEXT,       _( "Theme Text" ) },
-    { SI::TODO,         _( "Todo" ) },
-    { SI::TRASHED,      _( "Trashed" ) },
-    { SI::UNIT,         _( "Unit" ) },
-    { SI::VALUE_TYPE,   _( "Value Type" ) },
-    { SI::YEARLY,       _( "Yearly" ) },
-    { SI::YES,          _( "Yes" ) }
+    { SI::ADD,          N_( "ADD" ) },
+    { SI::AUTO,         N_( "Auto" ) },
+    { SI::AVERAGE,      N_( "Average" ) },
+    { SI::BOOLEAN,      N_( "Boolean" ) },
+    { SI::CANCELED,     N_( "Canceled" ) },
+    { SI::CATEGORY,     N_( "Category" ) },
+    { SI::CHANGED,      N_( "CHANGED" ) },
+    { SI::CHART_INTERVALS,  N_( "Chart Intervals" ) },
+    { SI::CHART_UNDERLAY,   N_( "Chart Underlay" ) },
+    { SI::COLOR,        N_( "Color" ) },
+    { SI::CUMULATIVE,   N_( "Cumulative" ) },
+    { SI::DATE,         N_( "Date" ) },
+    { SI::DEFINITION,   N_( "Definition" ) },
+    { SI::DELETED,      N_( "DELETED" ) },
+    { SI::DONE,         N_( "Done" ) },
+    { SI::EDIT_DATE,    N_( "Edit Date" ) },
+    { SI::FAVORED,      N_( "Favored" ) },
+    { SI::ID,           N_( "ID" ) },
+    { SI::SI_IGNORE,    N_( "IGNORE" ) },
+    { SI::INTACT,       N_( "INTACT" ) },
+    { SI::LANGUAGE,     N_( "Language" ) },
+    { SI::LOCATION,     N_( "Location" ) },
+    { SI::MAP_PATH,     N_( "Map Path" ) },
+    { SI::MONTHLY,      N_( "Monthly" ) },
+    { SI::NA,           N_( "N/A" ) },
+    { SI::NAME,         N_( "Name" ) },
+    { SI::NEW,          N_( "NEW" ) },
+    { SI::NO,           N_( "No" ) },
+    { SI::NONE,         N_( "None" ) },
+    { SI::OTHER,        N_( "OTHER" ) },
+    { SI::OVERWRITE,    N_( "OVERWRITE" ) },
+    { SI::PROGRESSED,   N_( "Progressed" ) },
+    { SI::TYPE_NAME,    N_( "Type Name" ) },
+    { SI::THEME,        N_( "Theme" ) },
+    { SI::THEME_BASE,   N_( "Theme Base" ) },
+    { SI::THEME_FONT,   N_( "Theme Font" ) },
+    { SI::THEME_HEADING,    N_( "Theme Heading" ) },
+    { SI::THEME_HIGHLIGHT,  N_( "Theme Highlight" ) },
+    { SI::THEME_SUBHEADING, N_( "Theme Subheading" ) },
+    { SI::THEME_TEXT,       N_( "Theme Text" ) },
+    { SI::TODO,         N_( "Todo" ) },
+    { SI::TRASHED,      N_( "Trashed" ) },
+    { SI::UNIT,         N_( "Unit" ) },
+    { SI::VALUE_TYPE,   N_( "Value Type" ) },
+    { SI::YEARLY,       N_( "Yearly" ) },
+    { SI::YES,          N_( "Yes" ) },
+
+    { SI::TAG,          N_( "Tag" ) },
+    { SI::PARAGRAPH,    N_( "Paragraph" ) }
 };
 
-inline Ustring
+static const StrMap STR_DATE =
+{
+    { SI::JANUARY,      N_( "January" ) },
+    { SI::FEBRUARY,     N_( "February" ) },
+    { SI::MARCH,        N_( "March" ) },
+    { SI::APRIL,        N_( "April" ) },
+    { SI::MAY,          N_( "May" ) },
+    { SI::JUNE,         N_( "June" ) },
+    { SI::JULY,         N_( "July" ) },
+    { SI::AUGUST,       N_( "August" ) },
+    { SI::SEPTEMBER,    N_( "September" ) },
+    { SI::OCTOBER,      N_( "October" ) },
+    { SI::NOVEMBER,     N_( "November" ) },
+    { SI::DECEMBER,     N_( "December" ) }
+};
+
+inline HELPERS::Ustring
 operator/( StrMap map, SI i )
-{ return map.at( i ); }
+{ return gettext( map.at( i ).c_str() ); }
 
 namespace STRING
 {
@@ -245,15 +280,21 @@ static const char TAG_WITH_ENTRIES_AVERAGE[] =
 static const char TAG_WITH_ENTRIES_CUMULATIVE[] =
         N_( "Tag with %1 entrie(s). Total value = %2" );
 
+static const char NEW_THEME_NAME[] =
+        N_( "New theme" );
+
 static const char NEW_CHAPTER_NAME[] =
         N_( "New chapter" );
 
 static const char NEW_CATEGORY_NAME[] =
         N_( "New category" );
 
-static const char DEFAULT_CHAPTER_CTG_NAME[] =
+static const char DEFAULT[] =
         N_( "Default" );
 
+static const char NONDISPOSABLE_DEFAULT[] =
+        N_( "<Default>" );
+
 } // namespace STRING
 
 } // namespace LIFO
