@@ -57,8 +57,8 @@ class UIEntry
         void                    remove_entry_from_history( Entry* );
         void                    clear_history();
 
-        bool                    does_title_need_refreshing()
-        { return( m_p2entry && m_L_title->get_text() != m_p2entry->get_title_str() ); }
+//        bool                    does_title_need_refreshing()
+//        { return( m_p2entry && m_L_title->get_text() != m_p2entry->get_title_str() ); }
         void                    refresh_title()
         {
             if( m_p2entry )
