@@ -388,13 +388,14 @@ Chart::draw( const Cairo::RefPtr< Cairo::Context >& cr )
 
     // y LABELS
     auto&& layout_ym{ Pango::Layout::create( cr ) };
+    layout_ym->set_font_description( m_font_main );
 
     cr->set_source_rgb( 0.1, 0.1, 0.1 );
     cr->move_to( BORDER_LABEL, s_y_min - label_y - OFFSET_LABEL );
     layout_ym->set_text( STR::format_number( m_v_max ) + " " + m_data.unit );
     layout_ym->show_in_cairo_context( cr );
 
-    cr->move_to( BORDER_LABEL, m_y_mid / 2 - label_y - OFFSET_LABEL );
+    cr->move_to( BORDER_LABEL, m_y_mid - label_y - OFFSET_LABEL );
     layout_ym->set_text(
             STR::format_number( ( m_v_max + m_v_min ) / 2 ) + " " + m_data.unit );
     layout_ym->show_in_cairo_context( cr );
@@ -410,8 +411,6 @@ Chart::draw( const Cairo::RefPtr< Cairo::Context >& cr )
     if( ( m_step_start + m_hovered_step ) > 0 )
         m_data.forward_date( date_hovered.m_date, m_step_start + m_hovered_step );
 
-    layout_ym->set_font_description( m_font_main );
-
     cr->set_source_rgb( 0.0, 0.0, 0.0 );
 
     for( int i = step_grid_first; i < ( int ) m_step_count; i+=step_grid )
