@@ -554,8 +554,7 @@ TextbufferDiary::apply_heading()
         it_end.forward_to_line_end();
     apply_tag( m_tag_heading, it_bgn, it_end );
 
-    if( ! m_flag_settext_operation && m_p2entry && m_ptr2diary &&
-        AppWindow::p->UI_entry->does_title_need_refreshing() )
+    if( ! m_flag_settext_operation && m_p2entry && m_ptr2diary )
     {
         AppWindow::p->UI_diary->handle_entry_title_changed( m_p2entry );
         AppWindow::p->UI_entry->refresh_title();
